==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/magnet/dialogs_bg.lua <==
dialogId("pap-v-ha", "font_big", "Look. Another energy source.")
dialogStr("Виж, алтернативен енергиен източник.")

dialogId("pap-m-magnet", "font_small", "Don’t worry. This magnet is here only to hinder us.")
dialogStr("Спокойно, този магнит е тук само за да ни пречи.")

dialogId("pap-v-potrebovat", "font_big", "I think we are going to need it.")
dialogStr("Мисля, че ще ни трябва.")

dialogId("pap-m-zvlastni", "font_small", "This is a very strange object.")
dialogStr("Този обект е доста странен.")

dialogId("pap-v-prekvapeni", "font_big", "I think that UFO is going to be full of such surprises.")
dialogStr("Мисля, че едно НЛО предполага доста изненади.")

dialogId("pap-m-teorie", "font_small", "Stop developing your theories and start solving.")
dialogStr("Стига си развивал теории и започвай с решението.")

dialogId("pap-m-radio", "font_small", "This looks like a radio.")
dialogStr("Това ми прилича на радио.")

dialogId("pap-v-radio", "font_big", "How could a radio get here?")
dialogStr("Как е могло радио да попадне тук?")

dialogId("pap-m-nechme", "font_small", "Let it be.")
dialogStr("Остави го.")

dialogId("pap-v-divny", "font_big", "This is a strange radio.")
dialogStr("Това радио е малко странно.")

dialogId("pap-m-coje", "font_small", "What have we here?")
dialogStr("Какво имаме тук?")

dialogId("pap-m-pistole", "font_small", "It looks like a pistol to me.")
dialogStr("Прилича ми на пистолет.")

dialogId("pap-v-laserova", "font_big", "Maybe it’s a laser weapon.")
dialogStr("Може би е лазерно оръжие.")

dialogId("pap-m-jejedno", "font_small", "It doesn’t matter. We don’t need it.")
dialogStr("Няма значение. Не ни трябва.")

dialogId("pap-v-nemir", "font_big", "Stop pointing at me with it!")
dialogStr("Стига си го насочвала към мен!")

dialogId("pap-m-nejde", "font_small", "As if you don’t know that you can’t turn objects in this game.")
dialogStr("Все едни не знаеш, че в тази игра обектите не могат да се въртят.")

dialogId("pap-m-ocel", "font_small", "There are too many steel constructions here.")
dialogStr("Тук има твърде много стоманени конструкции.")

dialogId("pap-v-vufu", "font_big", "Don’t forget that we are inside of the flying saucer!")
dialogStr("Не забравяй, че се намираме във вътрешността на летяща чиния!")

dialogId("pap-m-naucit", "font_small", "Maybe I could learn how to manipulate these steel tubes.")
dialogStr("Може би мога да се науча да манипулирам тези стоманени тръби.")

dialogId("pap-m-nepohnu", "font_small", "No, I can’t move it.")
dialogStr("Не, не мога да я помръдна.")

dialogId("pap-v-tesno", "font_big", "It’s quite tight here.")
dialogStr("Тук е доста тясно.")

dialogId("pap-m-mraz", "font_small", "These magnets are giving me the creeps.")
dialogStr("От тези магнити ме побиват тръпки.")

dialogId("pap-v-pole", "font_big", "This magnetic field probably has some invigorating effects.")
dialogStr("Това магнитно поле сигурно има ободряващ ефект.")

dialogId("pap-m-nedobre", "font_small", "It’s doing me no good.")
dialogStr("Не усещам никакво подобрение.")

==> fillets-ng-data_1.0.0.orig.tar.gz: fillets-ng-data-1.0.0/script/magnet/dialogs_bg.lua <==
dialogId("pap-v-ha", "font_big", "Look. Another energy source.")
dialogStr("Виж, алтернативен енергиен източник.")

dialogId("pap-m-magnet", "font_small", "Don’t worry. This magnet is here only to hinder us.")
dialogStr("Спокойно, този магнит е тук само за да ни пречи.")

dialogId("pap-v-potrebovat", "font_big", "I think we are going to need it.")
dialogStr("Мисля, че ще ни трябва.")

dialogId("pap-m-zvlastni", "font_small", "This is a very strange object.")
dialogStr("Този обект е доста странен.")

dialogId("pap-v-prekvapeni", "font_big", "I think that UFO is going to be full of such surprises.")
dialogStr("Мисля, че едно НЛО предполага доста изненади.")

dialogId("pap-m-teorie", "font_small", "Stop developing your theories and start solving.")
dialogStr("Стига си развивал теории и започвай с решението.")

dialogId("pap-m-radio", "font_small", "This looks like a radio.")
dialogStr("Това ми прилича на радио.")

dialogId("pap-v-radio", "font_big", "How could a radio get here?")
dialogStr("Как е могло радио да попадне тук?")

dialogId("pap-m-nechme", "font_small", "Let it be.")
dialogStr("Остави го.")

dialogId("pap-v-divny", "font_big", "This is a strange radio.")
dialogStr("Това радио е малко странно.")

dialogId("pap-m-coje", "font_small", "What have we here?")
dialogStr("Какво имаме тук?")

dialogId("pap-m-pistole", "font_small", "It looks like a pistol to me.")
dialogStr("Прилича ми на пистолет.")

dialogId("pap-v-laserova", "font_big", "Maybe it’s a laser weapon.")
dialogStr("Може би е лазерно оръжие.")

dialogId("pap-m-jejedno", "font_small", "It doesn’t matter. We don’t need it.")
dialogStr("Няма значение. Не ни трябва.")

dialogId("pap-v-nemir", "font_big", "Stop pointing at me with it!")
dialogStr("Стига си го насочвала към мен!")

dialogId("pap-m-nejde", "font_small", "As if you don’t know that you can’t turn objects in this game.")
dialogStr("Все едно не знаеш, че в тази игра обектите не могат да се въртят.")

dialogId("pap-m-ocel", "font_small", "There are too many steel constructions here.")
dialogStr("Тук има твърде много стоманени конструкции.")

dialogId("pap-v-vufu", "font_big", "Don’t forget that we are inside of the flying saucer!")
dialogStr("Не забравяй, че се намираме във вътрешността на летяща чиния!")

dialogId("pap-m-naucit", "font_small", "Maybe I could learn how to manipulate these steel tubes.")
dialogStr("Може би мога да се науча да манипулирам тези стоманени тръби.")

dialogId("pap-m-nepohnu", "font_small", "No, I can’t move it.")
dialogStr("Не, не мога да я помръдна.")

dialogId("pap-v-tesno", "font_big", "It’s quite tight here.")
dialogStr("Тук е доста тясно.")

dialogId("pap-m-mraz", "font_small", "These magnets are giving me the creeps.")
dialogStr("От тези магнити ме побиват тръпки.")

dialogId("pap-v-pole", "font_big", "This magnetic field probably has some invigorating effects.")
dialogStr("Това магнитно поле сигурно има ободряващ ефект.")

dialogId("pap-m-nedobre", "font_small", "It’s doing me no good.")
dialogStr("Не усещам никакво подобрение.")
